dinero.conversion.db


create-db-rate-providerclj

(create-db-rate-provider db table from-field to-field rate-field)
(create-db-rate-provider db table from-field to-field rate-field date-field)

Creates a function to fetch currency conversion rates from a database.

Creates a function to fetch currency conversion rates from a database.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries