dinero.format


format-moneyclj

(format-money money
              &
              {:keys [locale decimal-places rounding-mode symbol-style]
               :as _options})

Formats the given monetary amount with the given options.

Formats the given monetary amount with the given options.
sourceraw docstring

format-money-with-patternclj

(format-money-with-pattern money
                           pattern
                           &
                           {:keys [locale rounding-mode] :as _options})

Formats the given monetary amount with the given pattern and options.

Formats the given monetary amount with the given pattern and options.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries