(add & moneis)Adds the given monetary amounts.
Adds the given monetary amounts.
(divide money divisor)Divides the given monetary amount by the given divisor.
Divides the given monetary amount by the given divisor.
(money-abs money)Returns the absolute value of the given monetary amount.
Returns the absolute value of the given monetary amount.
(money-max & moneis)Returns the maximum of the given monetary amounts.
Returns the maximum of the given monetary amounts.
(money-min & moneis)Returns the minimum of the given monetary amounts.
Returns the minimum of the given monetary amounts.
(money-neg? money)Returns true if the given monetary amount is negative.
Returns true if the given monetary amount is negative.
(money-pos? money)Returns true if the given monetary amount is positive.
Returns true if the given monetary amount is positive.
(money-zero? money)Returns true if the given monetary amount is zero.
Returns true if the given monetary amount is zero.
(money< money-1 money-2)Returns true if the first monetary amount is less than the second monetary amount.
Returns true if the first monetary amount is less than the second monetary amount.
(money<= money-1 money-2)Returns true if the first monetary amount is less than or equal to the second monetary amount.
Returns true if the first monetary amount is less than or equal to the second monetary amount.
(money> money-1 money-2)Returns true if the first monetary amount is greater than the second monetary amount.
Returns true if the first monetary amount is greater than the second monetary amount.
(money>= money-1 money-2)Returns true if the first monetary amount is greater than or equal to the second monetary amount.
Returns true if the first monetary amount is greater than or equal to the second monetary amount.
(multiply money factor)Multiplies the given monetary amount by the given factor.
Multiplies the given monetary amount by the given factor.
(negate money)Negates the given monetary amount.
Negates the given monetary amount.
(subtract & moneis)Subtracts the given monetary amounts.
Subtracts the given monetary amounts.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |