(create-db-rate-provider db table from-field to-field rate-field)(create-db-rate-provider db table from-field to-field rate-field date-field)Creates a function to fetch currency conversion rates from a database.
Creates a function to fetch currency conversion rates from a database.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |