(format-money money
&
{:keys [locale decimal-places rounding-mode symbol-style]
:as _options})Formats the given monetary amount with the given options.
Formats the given monetary amount with the given options.
(format-money-with-pattern money
pattern
&
{:keys [locale rounding-mode] :as _options})Formats the given monetary amount with the given pattern and options.
Formats the given monetary amount with the given pattern and options.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |